@@ -8,6 +8,6 @@ __all__ = filters.__all__
 
 class BooleanFilter(filters.BooleanFilter):
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('widget', BooleanWidget)
+        kwargs.setdefault("widget", BooleanWidget)
 
         super().__init__(*args, **kwargs)
