@@ -4,6 +4,7 @@ import unittest
 from operator import attrgetter
 from unittest import mock
 
+import django
 from django import forms
 from django.http import QueryDict
 from django.test import TestCase, override_settings
@@ -13,6 +14,7 @@ from django.utils.timezone import make_aware, now
 from django_filters.filters import (
     AllValuesFilter,
     AllValuesMultipleFilter,
+    BaseInFilter,
     CharFilter,
     ChoiceFilter,
     DateFromToRangeFilter,
@@ -30,6 +32,7 @@ from django_filters.filters import (
     TypedMultipleChoiceFilter,
 )
 from django_filters.filterset import FilterSet
+from django_filters.widgets import QueryArrayWidget
 
 from .models import (
     STATUS_CHOICES,
@@ -847,6 +850,7 @@ class DateFromToRangeFilterTests(TestCase):
         )
         self.assertEqual(len(results.qs), 3)
 
+    @unittest.skipUnless(django.VERSION < (5, 0), "is_dst removed in Django 5.0")
     @override_settings(TIME_ZONE="America/Sao_Paulo")
     def test_filtering_dst_start_midnight(self):
         tz = timezone.get_default_timezone()
@@ -875,6 +879,7 @@ class DateFromToRangeFilterTests(TestCase):
         )
         self.assertEqual(len(results.qs), 2)
 
+    @unittest.skipUnless(django.VERSION < (5, 0), "is_dst removed in Django 5.0")
     @override_settings(TIME_ZONE="America/Sao_Paulo")
     def test_filtering_dst_ends_midnight(self):
         tz = timezone.get_default_timezone()
@@ -903,6 +908,7 @@ class DateFromToRangeFilterTests(TestCase):
         )
         self.assertEqual(len(results.qs), 2)
 
+    @unittest.skipUnless(django.VERSION < (5, 0), "is_dst removed in Django 5.0")
     @override_settings(TIME_ZONE="Europe/Paris")
     def test_filtering_dst_start(self):
         tz = timezone.get_default_timezone()
@@ -934,6 +940,7 @@ class DateFromToRangeFilterTests(TestCase):
         )
         self.assertEqual(len(results.qs), 3)
 
+    @unittest.skipUnless(django.VERSION < (5, 0), "is_dst removed in Django 5.0")
     @override_settings(TIME_ZONE="Europe/Paris")
     def test_filtering_dst_end(self):
         tz = timezone.get_default_timezone()
@@ -1972,10 +1979,10 @@ class OrderingFilterTests(TestCase):
 
 class MiscFilterSetTests(TestCase):
     def setUp(self):
-        User.objects.create(username="alex", status=1)
-        User.objects.create(username="jacob", status=2)
-        User.objects.create(username="aaron", status=2)
-        User.objects.create(username="carl", status=0)
+        User.objects.create(username="alex", last_name="johnson", status=1)
+        User.objects.create(username="jacob", last_name="johnson", status=2)
+        User.objects.create(username="aaron", last_name="white", status=2)
+        User.objects.create(username="carl", last_name="black", status=0)
 
     def test_filtering_with_declared_filters(self):
         class F(FilterSet):
@@ -2051,3 +2058,36 @@ class MiscFilterSetTests(TestCase):
         f = F({"status": "2"}, queryset=qs)
         self.assertEqual(len(f.qs), 2)
         self.assertEqual(f.qs.count(), 2)
+
+    def test_filtering_with_widgets(self):
+        class CharInFilter(BaseInFilter, CharFilter):
+            pass
+
+        class F(FilterSet):
+            last_name = CharInFilter(widget=QueryArrayWidget)
+            username = CharInFilter()
+
+            class Meta:
+                model = User
+                fields = ["last_name", "username"]
+
+        qs = User.objects.all()
+
+        f = F({"last_name": ["johnson"]}, queryset=qs)
+        self.assertQuerysetEqual(
+            f.qs, ["alex", "jacob"], lambda o: o.username, ordered=False
+        )
+
+        f = F({"last_name": ["johnson"], "username": "carl"}, queryset=qs)
+        self.assertQuerysetEqual(f.qs, [], lambda o: o.username, ordered=False)
+
+        f = F({"last_name": ["johnson"], "username": "jacob"}, queryset=qs)
+        self.assertQuerysetEqual(f.qs, ["jacob"], lambda o: o.username, ordered=False)
+
+        f = F(
+            {"last_name": ["johnson", "white"], "username": "jacob, carl, aaron"},
+            queryset=qs,
+        )
+        self.assertQuerysetEqual(
+            f.qs, ["jacob", "aaron"], lambda o: o.username, ordered=False
+        )
